==> hs-checkers-0.2.9_1.tbz: lib/ghc-7.4.1/cabal/checkers-0.2.9/register.sh <==
#!/bin/sh
echo 'name: checkers
version: 0.2.9
id: checkers-0.2.9-764664bde718635567a699be9a380516

license: BSD3
copyright: (c) 2008 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage: http://haskell.org/haskellwiki/checkers
package-url: http://code.haskell.org/checkers
synopsis: Check properties on standard classes and data structures.
description: '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
             standard type classes as QuickCheck properties.  Also some morphism
             properties.  It also provides arbitrary instances and generator combinators
             for common data types.
             .
             Project wiki page: <http://haskell.org/haskellwiki/checkers>
             .
             &#169; 2008 by Conal Elliott; BSD3 license.
             .
             Contributions from: Thomas Davie.
category: Testing
author: Conal Elliott
exposed: True
exposed-modules: Test.QuickCheck.Utils Test.QuickCheck.Checkers
                 Test.QuickCheck.Classes Test.QuickCheck.Bottoms
                 Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
                 Test.QuickCheck.Instances.Char Test.QuickCheck.Instances.Eq
                 Test.QuickCheck.Instances.List Test.QuickCheck.Instances.Maybe
                 Test.QuickCheck.Instances.Num Test.QuickCheck.Instances.Ord
                 Test.QuickCheck.Instances.Tuple Test.QuickCheck.Later
hidden-modules: Control.Monad.Extensions
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/checkers-0.2.9
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/checkers-0.2.9
              /usr/local/lib
hs-libraries: HScheckers-0.2.9
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.2-5e1b443b0b725755bf380173d85ffb73
         array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         random-1.0.1.1-7f9342c90214b9289fdaf20c9e2f867f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/checkers-0.2.9/html/checkers.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/checkers-0.2.9/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-checkers-0.3.1.tbz: lib/ghc-7.4.2/cabal/checkers-0.3.1/register.sh <==
#!/bin/sh
echo 'name: checkers
version: 0.3.1
id: checkers-0.3.1-6f57a9339d2bebf1404f2dbb36944905

license: BSD3
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
stability: experimental
homepage:
package-url:
synopsis: Check properties on standard classes and data structures.
description: '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
             standard type classes as QuickCheck properties.  Also some morphism
             properties.  It also provides arbitrary instances and generator combinators
             for common data types.
             .
             &#169; 2008-2013 by Conal Elliott; BSD3 license.
             .
             Contributions from: Thomas Davie.
category: Testing
author: Conal Elliott
exposed: True
exposed-modules: Test.QuickCheck.Utils Test.QuickCheck.Checkers
                 Test.QuickCheck.Classes Test.QuickCheck.Bottoms
                 Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
                 Test.QuickCheck.Instances.Char Test.QuickCheck.Instances.Eq
                 Test.QuickCheck.Instances.List Test.QuickCheck.Instances.Maybe
                 Test.QuickCheck.Instances.Num Test.QuickCheck.Instances.Ord
                 Test.QuickCheck.Instances.Tuple Test.QuickCheck.Later
hidden-modules: Control.Monad.Extensions
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/checkers-0.3.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/checkers-0.3.1
              /usr/local/lib
hs-libraries: HScheckers-0.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.5.1.1-b0101c9f2f49da67b606fa3478ecc4d1
         array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         random-1.0.1.1-fb8963ffa6ffa7a0a448fb912ed467a3
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/checkers-0.3.1/html/checkers.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/checkers-0.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
